@@ -2,33 +2,33 @@ var searchData=
 [
   ['tan_0',['tan',['../a00534.html#ac96b7a51e7ac1923b3b1d1e85fbff53b',1,'rtl::math']]],
   ['terminate_1',['terminate',['../a00878.html#af7ffa642d68ae530bc76b12ca5852ca6',1,'osl::Thread']]],
-  ['thread_2',['thread',['../a00598.html#a1b544964df8448966d54099c5ecf2918',1,'salhelper::Thread::Thread()'],['../a00878.html#a354d6ff717692c854543da069c493a6a',1,'osl::Thread::Thread()']]],
+  ['thread_2',['Thread',['../a00598.html#a1b544964df8448966d54099c5ecf2918',1,'salhelper::Thread::Thread()'],['../a00878.html#a354d6ff717692c854543da069c493a6a',1,'osl::Thread::Thread()']]],
   ['threaddata_3',['ThreadData',['../a00882.html#a3fac11314cd8ba1fb612a8ccf844d5cc',1,'osl::ThreadData']]],
   ['threadfunc_4',['threadFunc',['../a00530.html#a919fa4231771ea453e5996b0e288807a',1,'osl']]],
   ['throwexception_5',['throwException',['../a00537.html#ab48786c964739bb4afd274eb637dce5e',1,'cppu']]],
   ['timedout_6',['timedout',['../a00566.html#ad660f435988878cc089e7a5835703c66',1,'salhelper::ConditionWaiter::timedout::timedout()'],['../a00566.html#af7d5cc7e5c516a587e06fdc9c3e7c636',1,'salhelper::ConditionWaiter::timedout::timedout(timedout const &amp;)']]],
-  ['timer_7',['timer',['../a00606.html#acdd49db9d293bbc30672ea2858bc3b85',1,'salhelper::Timer::Timer()'],['../a00606.html#a1d857a42398e461242c0f9082e6eaa9e',1,'salhelper::Timer::Timer(const TTimeValue &amp;Time)'],['../a00606.html#a3998be53d29e0709c891a1939ec45c23',1,'salhelper::Timer::Timer(const TTimeValue &amp;Time, const TTimeValue &amp;RepeatTime)']]],
-  ['toany_8',['toany',['../a00536.html#aa96d250594e70eadc0181a2f7082772b',1,'com::sun::star::uno::toAny(T const &amp;value)'],['../a00536.html#a80d03f5ef676c2eadc725ffcebecc19a',1,'com::sun::star::uno::toAny(Any const &amp;value)'],['../a00536.html#a80d03f5ef676c2eadc725ffcebecc19a',1,'com::sun::star::uno::toAny(Any const &amp;value)']]],
-  ['toasciilowercase_9',['toasciilowercase',['../a00532.html#afb3966d4a425a6aa5a0d7b0711e156f9',1,'rtl::toAsciiLowerCase()'],['../a00754.html#a118306d973a7555969aa66c2f31929b5',1,'rtl::OUString::toAsciiLowerCase()'],['../a00666.html#ab2cb2ab8770c0518c5f9aa5f19cd62a9',1,'rtl::OString::toAsciiLowerCase()']]],
-  ['toasciiuppercase_10',['toasciiuppercase',['../a00532.html#ac8375dc6645b3a6992c89547d324ae05',1,'rtl::toAsciiUpperCase()'],['../a00754.html#adae1017ecd480dc311d1568662deaf31',1,'rtl::OUString::toAsciiUpperCase()'],['../a00666.html#a421460a253ce22a1c156a277416ce62b',1,'rtl::OString::toAsciiUpperCase()']]],
-  ['toboolean_11',['toboolean',['../a00754.html#afc6da0c7b633023da7a59c37d41bbe65',1,'rtl::OUString::toBoolean()'],['../a00666.html#a4df92ed3fa7053f1b59c2a12f2310e3c',1,'rtl::OString::toBoolean()']]],
-  ['tochar_12',['tochar',['../a00754.html#acb464eafd88afa6e95300d79b00fd217',1,'rtl::OUString::toChar()'],['../a00666.html#a46498797c37a21161a4c680de4042bb6',1,'rtl::OString::toChar() const']]],
-  ['todouble_13',['todouble',['../a00666.html#adf97e645626c5f3211d4c5e4886fced1',1,'rtl::OString::toDouble()'],['../a00754.html#a96b0ba367b010c14c58c220de3b5a677',1,'rtl::OUString::toDouble()']]],
-  ['tofloat_14',['tofloat',['../a00666.html#abdaa863f070efbbba3217f153e86b597',1,'rtl::OString::toFloat()'],['../a00754.html#a3cd23f1fcfa3b3592f58521e6ef81858',1,'rtl::OUString::toFloat()']]],
-  ['toint32_15',['toint32',['../a00666.html#ad32f2cb5209536626f9c480eead0fdde',1,'rtl::OString::toInt32()'],['../a00754.html#a219d053853643733ed7e5968b419cea3',1,'rtl::OUString::toInt32()']]],
-  ['toint64_16',['toint64',['../a00666.html#ad0ab2ecd6a337e72e748f52bcdfd40b1',1,'rtl::OString::toInt64()'],['../a00754.html#a8ae42d2bae89ab790eea5086ef2f3e4b',1,'rtl::OUString::toInt64()']]],
+  ['timer_7',['Timer',['../a00606.html#acdd49db9d293bbc30672ea2858bc3b85',1,'salhelper::Timer::Timer()'],['../a00606.html#a1d857a42398e461242c0f9082e6eaa9e',1,'salhelper::Timer::Timer(const TTimeValue &amp;Time)'],['../a00606.html#a3998be53d29e0709c891a1939ec45c23',1,'salhelper::Timer::Timer(const TTimeValue &amp;Time, const TTimeValue &amp;RepeatTime)']]],
+  ['toany_8',['toAny',['../a00536.html#aa96d250594e70eadc0181a2f7082772b',1,'com::sun::star::uno::toAny(T const &amp;value)'],['../a00536.html#a80d03f5ef676c2eadc725ffcebecc19a',1,'com::sun::star::uno::toAny(Any const &amp;value)'],['../a00536.html#a80d03f5ef676c2eadc725ffcebecc19a',1,'com::sun::star::uno::toAny(Any const &amp;value)']]],
+  ['toasciilowercase_9',['toAsciiLowerCase',['../a00666.html#ab2cb2ab8770c0518c5f9aa5f19cd62a9',1,'rtl::OString::toAsciiLowerCase()'],['../a00754.html#a118306d973a7555969aa66c2f31929b5',1,'rtl::OUString::toAsciiLowerCase()'],['../a00532.html#afb3966d4a425a6aa5a0d7b0711e156f9',1,'rtl::toAsciiLowerCase()']]],
+  ['toasciiuppercase_10',['toAsciiUpperCase',['../a00666.html#a421460a253ce22a1c156a277416ce62b',1,'rtl::OString::toAsciiUpperCase()'],['../a00754.html#adae1017ecd480dc311d1568662deaf31',1,'rtl::OUString::toAsciiUpperCase()'],['../a00532.html#ac8375dc6645b3a6992c89547d324ae05',1,'rtl::toAsciiUpperCase()']]],
+  ['toboolean_11',['toBoolean',['../a00666.html#a4df92ed3fa7053f1b59c2a12f2310e3c',1,'rtl::OString::toBoolean()'],['../a00754.html#afc6da0c7b633023da7a59c37d41bbe65',1,'rtl::OUString::toBoolean()']]],
+  ['tochar_12',['toChar',['../a00666.html#a46498797c37a21161a4c680de4042bb6',1,'rtl::OString::toChar()'],['../a00754.html#acb464eafd88afa6e95300d79b00fd217',1,'rtl::OUString::toChar()']]],
+  ['todouble_13',['toDouble',['../a00666.html#adf97e645626c5f3211d4c5e4886fced1',1,'rtl::OString::toDouble()'],['../a00754.html#a96b0ba367b010c14c58c220de3b5a677',1,'rtl::OUString::toDouble()']]],
+  ['tofloat_14',['toFloat',['../a00666.html#abdaa863f070efbbba3217f153e86b597',1,'rtl::OString::toFloat()'],['../a00754.html#a3cd23f1fcfa3b3592f58521e6ef81858',1,'rtl::OUString::toFloat()']]],
+  ['toint32_15',['toInt32',['../a00666.html#ad32f2cb5209536626f9c480eead0fdde',1,'rtl::OString::toInt32()'],['../a00754.html#a219d053853643733ed7e5968b419cea3',1,'rtl::OUString::toInt32()']]],
+  ['toint64_16',['toInt64',['../a00666.html#ad0ab2ecd6a337e72e748f52bcdfd40b1',1,'rtl::OString::toInt64()'],['../a00754.html#a8ae42d2bae89ab790eea5086ef2f3e4b',1,'rtl::OUString::toInt64()']]],
   ['topointer_17',['toPointer',['../a00710.html#a027f3c945cf002b657b042fccfd4d23f',1,'rtl::libreoffice_internal::ConstCharArrayDetector&lt; const char[N], T &gt;']]],
-  ['tostring_18',['tostring',['../a00662.html#a965537f83678d992905897020d0e2269',1,'rtl::OStringBuffer::toString()'],['../a00750.html#a7c9dd7d083321e2dbb65902e4bf6d8ec',1,'rtl::OUStringBuffer::toString()']]],
-  ['touint32_19',['touint32',['../a00754.html#a8c37a38e8fc27aa24e03f56744db65c1',1,'rtl::OUString::toUInt32()'],['../a00666.html#af6d3f89160f5499192513fc13879ba62',1,'rtl::OString::toUInt32()']]],
-  ['touint64_20',['touint64',['../a00754.html#a556cf4161fb21ac199ee8642141c30bd',1,'rtl::OUString::toUInt64()'],['../a00666.html#a360c1fd2ff6962155edaac9507b7793b',1,'rtl::OString::toUInt64()']]],
+  ['tostring_18',['toString',['../a00662.html#a965537f83678d992905897020d0e2269',1,'rtl::OStringBuffer::toString()'],['../a00750.html#a7c9dd7d083321e2dbb65902e4bf6d8ec',1,'rtl::OUStringBuffer::toString()']]],
+  ['touint32_19',['toUInt32',['../a00666.html#af6d3f89160f5499192513fc13879ba62',1,'rtl::OString::toUInt32()'],['../a00754.html#a8c37a38e8fc27aa24e03f56744db65c1',1,'rtl::OUString::toUInt32()']]],
+  ['touint64_20',['toUInt64',['../a00666.html#a360c1fd2ff6962155edaac9507b7793b',1,'rtl::OString::toUInt64()'],['../a00754.html#a556cf4161fb21ac199ee8642141c30bd',1,'rtl::OUString::toUInt64()']]],
   ['tounosequence_21',['toUnoSequence',['../a00536.html#a05106795b49bd149a6487d14789b3264',1,'com::sun::star::uno']]],
   ['toutf8_22',['toUtf8',['../a00754.html#a5a22f494be1c086c128a90aee7ba1d3a',1,'rtl::OUString']]],
-  ['trim_23',['trim',['../a00754.html#ada382233aa04a3aca8a86d71f5795b17',1,'rtl::OUString::trim()'],['../a00666.html#aa9730096cd3996bb196d1e4c48ca8899',1,'rtl::OString::trim()']]],
+  ['trim_23',['trim',['../a00666.html#aa9730096cd3996bb196d1e4c48ca8899',1,'rtl::OString::trim()'],['../a00754.html#ada382233aa04a3aca8a86d71f5795b17',1,'rtl::OUString::trim()']]],
   ['truncate_24',['truncate',['../a00750.html#ab9dfc7570d6df3bd659ec1032930f899',1,'rtl::OUStringBuffer']]],
   ['trytoacquire_25',['tryToAcquire',['../a00814.html#afb75796aa4854379ad4618922c91562f',1,'osl::Mutex']]],
-  ['ttimevalue_26',['ttimevalue',['../a00602.html#a5ca3f5190548d6c6fcb4fba8cbb01837',1,'salhelper::TTimeValue::TTimeValue(const TimeValue &amp;rTimeValue)'],['../a00602.html#a6e75ce9497b450b51ecf660e3d459dda',1,'salhelper::TTimeValue::TTimeValue(sal_uInt32 MilliSecs)'],['../a00602.html#a9557145962e72ae22232fafe8d8195fe',1,'salhelper::TTimeValue::TTimeValue(sal_uInt32 Secs, sal_uInt32 Nano)'],['../a00602.html#ae4c1362936923b2d7eb2f3bc843469f5',1,'salhelper::TTimeValue::TTimeValue()']]],
-  ['type_27',['type',['../a01974.html#a763a9f04707895b340777c34e70d6ad0',1,'com::sun::star::uno::Type::Type(typelib_TypeDescriptionReference *pType, __sal_NoAcquire dummy)'],['../a01974.html#a7c800af2c1fb97312da44f942dc62459',1,'com::sun::star::uno::Type::Type(const Type &amp;rType)'],['../a01974.html#ab1bad8d7c5cde72f63b71388e8e1b2ff',1,'com::sun::star::uno::Type::Type(typelib_TypeDescriptionReference *pType, UnoType_NoAcquire dummy)'],['../a01974.html#ac7baba5c6dc7c52f4df3bdb15c26dd7e',1,'com::sun::star::uno::Type::Type(typelib_TypeDescriptionReference *pType)'],['../a01974.html#aeb3748c0c67a5af7cec2af155125c206',1,'com::sun::star::uno::Type::Type(TypeClass eTypeClass, const char *pTypeName)'],['../a01974.html#a5ebb5b568d42adc4eae85a211c06179e',1,'com::sun::star::uno::Type::Type(TypeClass eTypeClass, const ::rtl::OUString &amp;rTypeName)'],['../a01974.html#a89ffc2ae6bdf545544e69eaa7bfa5552',1,'com::sun::star::uno::Type::Type()']]],
-  ['typedescription_28',['typedescription',['../a00950.html#a01de1d723d0abe7d8d9757075d0f122f',1,'com::sun::star::uno::TypeDescription::TypeDescription(typelib_TypeDescription *pTypeDescr=NULL)'],['../a00950.html#a2f7fa47976e3fa073add0ca0d7c44903',1,'com::sun::star::uno::TypeDescription::TypeDescription(rtl_uString *pTypeName)'],['../a00950.html#af7fe6f21c3438c12db6aa143e5a2061b',1,'com::sun::star::uno::TypeDescription::TypeDescription(const ::rtl::OUString &amp;rTypeName)'],['../a00950.html#af3ec54e72f35fc8f1332b9b4923e91d0',1,'com::sun::star::uno::TypeDescription::TypeDescription(typelib_TypeDescriptionReference *pTypeDescrRef)'],['../a00950.html#af296ca0324da748b0e0bce8e9958a059',1,'com::sun::star::uno::TypeDescription::TypeDescription(const TypeDescription &amp;rDescr)'],['../a00950.html#a86456d867afceba7bf1db38e179a1b87',1,'com::sun::star::uno::TypeDescription::TypeDescription(const css::uno::Type &amp;rType)']]],
+  ['ttimevalue_26',['TTimeValue',['../a00602.html#ae4c1362936923b2d7eb2f3bc843469f5',1,'salhelper::TTimeValue::TTimeValue()'],['../a00602.html#a9557145962e72ae22232fafe8d8195fe',1,'salhelper::TTimeValue::TTimeValue(sal_uInt32 Secs, sal_uInt32 Nano)'],['../a00602.html#a6e75ce9497b450b51ecf660e3d459dda',1,'salhelper::TTimeValue::TTimeValue(sal_uInt32 MilliSecs)'],['../a00602.html#a5ca3f5190548d6c6fcb4fba8cbb01837',1,'salhelper::TTimeValue::TTimeValue(const TimeValue &amp;rTimeValue)']]],
+  ['type_27',['Type',['../a01974.html#a89ffc2ae6bdf545544e69eaa7bfa5552',1,'com::sun::star::uno::Type::Type()'],['../a01974.html#a5ebb5b568d42adc4eae85a211c06179e',1,'com::sun::star::uno::Type::Type(TypeClass eTypeClass, const ::rtl::OUString &amp;rTypeName)'],['../a01974.html#aeb3748c0c67a5af7cec2af155125c206',1,'com::sun::star::uno::Type::Type(TypeClass eTypeClass, const char *pTypeName)'],['../a01974.html#ac7baba5c6dc7c52f4df3bdb15c26dd7e',1,'com::sun::star::uno::Type::Type(typelib_TypeDescriptionReference *pType)'],['../a01974.html#ab1bad8d7c5cde72f63b71388e8e1b2ff',1,'com::sun::star::uno::Type::Type(typelib_TypeDescriptionReference *pType, UnoType_NoAcquire dummy)'],['../a01974.html#a763a9f04707895b340777c34e70d6ad0',1,'com::sun::star::uno::Type::Type(typelib_TypeDescriptionReference *pType, __sal_NoAcquire dummy)'],['../a01974.html#a7c800af2c1fb97312da44f942dc62459',1,'com::sun::star::uno::Type::Type(const Type &amp;rType)']]],
+  ['typedescription_28',['TypeDescription',['../a00950.html#a01de1d723d0abe7d8d9757075d0f122f',1,'com::sun::star::uno::TypeDescription::TypeDescription(typelib_TypeDescription *pTypeDescr=NULL)'],['../a00950.html#af3ec54e72f35fc8f1332b9b4923e91d0',1,'com::sun::star::uno::TypeDescription::TypeDescription(typelib_TypeDescriptionReference *pTypeDescrRef)'],['../a00950.html#a86456d867afceba7bf1db38e179a1b87',1,'com::sun::star::uno::TypeDescription::TypeDescription(const css::uno::Type &amp;rType)'],['../a00950.html#af296ca0324da748b0e0bce8e9958a059',1,'com::sun::star::uno::TypeDescription::TypeDescription(const TypeDescription &amp;rDescr)'],['../a00950.html#a2f7fa47976e3fa073add0ca0d7c44903',1,'com::sun::star::uno::TypeDescription::TypeDescription(rtl_uString *pTypeName)'],['../a00950.html#af7fe6f21c3438c12db6aa143e5a2061b',1,'com::sun::star::uno::TypeDescription::TypeDescription(const ::rtl::OUString &amp;rTypeName)']]],
   ['typelib_5fsetcachesize_29',['typelib_setCacheSize',['../a00251.html#af9605511a417960160e304cfb5cd36a2',1,'typedescription.h']]],
   ['typelib_5fstatic_5fcompound_5ftype_5finit_30',['typelib_static_compound_type_init',['../a00251.html#a5c2fca70c17368051181aad9795314ed',1,'typedescription.h']]],
   ['typelib_5fstatic_5fenum_5ftype_5finit_31',['typelib_static_enum_type_init',['../a00251.html#a473bbbb980fbe7dbe41ad5b12f132d75',1,'typedescription.h']]],
