@@ -3,7 +3,7 @@ var searchData=
   ['rbhelper_0',['rBHelper',['../a01922.html#a87ecf89272ecccc6d4d8a9cc2ab76938',1,'cppu::OPropertySetHelper']]],
   ['registerinterface_1',['registerInterface',['../a00978.html#ae8144d834b499ad83b92ca40b1f5e290',1,'_uno_ExtEnvironment']]],
   ['registerproxyinterface_2',['registerProxyInterface',['../a00978.html#adbab8cb6e7cb9653c204e1b3f912d4c7',1,'_uno_ExtEnvironment']]],
-  ['release_3',['release',['../a00738.html#a11ee8616cb9f36bc97ff20b0b6ce9149',1,'_rtl_ModuleCount::release()'],['../a00966.html#aa860b6c6be060716fcabd7cbf2b225ab',1,'_uno_Interface::release()'],['../a00974.html#ab9ef55ce8173798c7dd7e593cd407e3e',1,'_uno_Environment::release()'],['../a00986.html#a1ebaf30ad0463d83e9003fd51a8173df',1,'_uno_Mapping::release()']]],
+  ['release_3',['release',['../a00738.html#a11ee8616cb9f36bc97ff20b0b6ce9149',1,'_rtl_ModuleCount::release'],['../a00966.html#aa860b6c6be060716fcabd7cbf2b225ab',1,'_uno_Interface::release'],['../a00974.html#ab9ef55ce8173798c7dd7e593cd407e3e',1,'_uno_Environment::release'],['../a00986.html#a1ebaf30ad0463d83e9003fd51a8173df',1,'_uno_Mapping::release']]],
   ['releaseinterface_4',['releaseInterface',['../a00978.html#a21c66992398cc4ddf7ea0b9a3f337718',1,'_uno_ExtEnvironment']]],
   ['releaseweak_5',['releaseWeak',['../a00974.html#a0ea72e3b9f6628108398a5c8aa15166f',1,'_uno_Environment']]],
   ['reserved_6',['Reserved',['../a00734.html#a23b0f444733c9da0f6b548d9af2a14eb',1,'_rtl_TextEncodingInfo']]],
